@@ -2,7 +2,8 @@ import re
 import os
 import threading
 import time
-from .utils import getLogger
+from typing import IO
+from kea2.utils import getLogger
 
 
 logger = getLogger(__name__)
@@ -20,47 +21,43 @@ def thread_excepthook(args):
 
 class LogWatcher:
 
-    def watcher(self, poll_interval=0.5):
-        self.buffer = ""
+    def watcher(self, poll_interval=3):
         self.last_pos = 0
 
-        while not self.end_flag:
-            self.read_log()
-            time.sleep(poll_interval)
+        with open(self.log_file, "r") as fp:
+            while not self.end_flag:
+                self.read_log(fp)
+                time.sleep(poll_interval)
+            
+            time.sleep(0.2)
+            self.read_log(fp)
         
-        time.sleep(0.2)
-        self.read_log()
-        
-    def read_log(self):
-        with open(self.log_file, 'r', encoding='utf-8') as f:
-            f.seek(self.last_pos)
-            new_data = f.read()
-            self.last_pos = f.tell()
+    def read_log(self, f: IO):
+        f.seek(self.last_pos)
+        buffer = f.read()
+        self.last_pos = f.tell()
 
-            if new_data:
-                self.buffer += new_data
-            self.parse_log()
+        self.parse_log(buffer)
 
-    def parse_log(self):
-        buffer = self.buffer
-        exception_match = PATTERN_EXCEPTION.search(buffer)
+    def parse_log(self, content):
+        exception_match = PATTERN_EXCEPTION.search(content)
         if exception_match:
             exception_body = exception_match.group(1).strip()
             if exception_body:
                 raise RuntimeError(
-                    "[Error] Execption while running fastbot:\n" + 
+                    "[Error] Fatal Execption while running fastbot:\n" + 
                     exception_body + 
                     "\nSee fastbot.log for details."
                 )
-        if self.end_flag:
-            statistic_match = PATTERN_STATISTIC.search(buffer)
-            if statistic_match:
-                statistic_body = statistic_match.group(1).strip()
-                if statistic_body:
-                    print(
-                        "[INFO] Fastbot exit:\n" + 
-                        statistic_body
-                    , flush=True)
+        
+        statistic_match = PATTERN_STATISTIC.search(content)
+        if statistic_match:
+            statistic_body = statistic_match.group(1).strip()
+            if statistic_body:
+                print(
+                    "[INFO] Fastbot exit:\n" + 
+                    statistic_body
+                , flush=True)
 
     def __init__(self, log_file):
         logger.info(f"Watching log: {log_file}")
@@ -79,4 +76,4 @@ class LogWatcher:
 
 
 if __name__ == "__main__":
-    LogWatcher("fastbot.log")
\ No newline at end of file
+    LogWatcher("/Users/atria/Desktop/coding/Kea2/output/res_2025062510_0420056539/fastbot_2025062510_0420056539.log")
\ No newline at end of file
